using System;
using System.Collections.Generic;
using System.Drawing;
using System.Windows.Forms;
using System.IO;
using System.Xml;
using GrapeCity.ActiveReports.Design;
using GrapeCity.ActiveReports.Design.Resources;
using System.Data.OleDb;
using System.Text;
namespace GrapeCity.ActiveReports.Samples.CreateReport
{
    public partial class ReportsForm : Form
    {
        public ReportsForm()
        {
            InitializeComponent();
            reportDesigner.NewReport(DesignerReportType.Page);//Sets the designer to create a blank page based report
            //Populating the ToolBox,reportExplorer and Propertygrid
            reportDesigner.Toolbox = reportToolbox;//Attaches the toolbox to the report designer
            reportExplorer.ReportDesigner = reportDesigner;//Attaches the report explorer to the report designer
            this.Icon = Properties.Resources.arLogo_32;
            groupEditor.ReportDesigner = reportDesigner;
            reportsLibrary.ReportDesigner = reportDesigner;
            reportDesigner.PropertyGrid = propertyGrid;//Attaches the Property Grid to the report designer
            //Populating the Menu
            ToolStrip toolStrip = reportDesigner.CreateToolStrips(new DesignerToolStrips[]
				{
					DesignerToolStrips.Menu
				})[0];
            ToolStripDropDownItem fileMenu = (ToolStripDropDownItem)toolStrip.Items[0];
            CreateFileMenu(fileMenu);
            AppendToolStrips(0, new ToolStrip[]
				{
					toolStrip
				});
            AppendToolStrips(1, reportDesigner.CreateToolStrips(new DesignerToolStrips[]
				{
					DesignerToolStrips.Edit, 
					DesignerToolStrips.Undo, 
					DesignerToolStrips.Zoom
				}));
            AppendToolStrips(1, new ToolStrip[]
				{
					CreateReportToolbar()
				});
            AppendToolStrips(2, reportDesigner.CreateToolStrips(new DesignerToolStrips[]
	            {
					DesignerToolStrips.Format, 
					DesignerToolStrips.Layout
	            }));
        }
        //Adding DropDownItems to the ToolStripDropDownItem
        private void CreateFileMenu(ToolStripDropDownItem fileMenu)
        {
            fileMenu.DropDownItems.Clear();
            fileMenu.DropDownItems.Add(new ToolStripMenuItem("½", Properties.Resources.CmdNewReport, new EventHandler(OnNew), (Keys.Control | Keys.N)));
            fileMenu.DropDownItems.Add(new ToolStripMenuItem("", Properties.Resources.CmdOpen, new EventHandler(OnOpen), (Keys.Control | Keys.O)));
            fileMenu.DropDownItems.Add(new ToolStripMenuItem("", Properties.Resources.CmdSave, new EventHandler(OnSave), (Keys.Control | Keys.S)));
            fileMenu.DropDownItems.Add(new ToolStripMenuItem("Ϊ", Properties.Resources.CmdSaveAs, new EventHandler(OnSaveAs)));
            
            // Ԥ˵
            fileMenu.DropDownItems.Add(new ToolStripMenuItem("Ԥ", null, new EventHandler(OnViewReport)));

            fileMenu.DropDownItems.Add(new ToolStripSeparator());
            fileMenu.DropDownItems.Add(new ToolStripMenuItem("˳", null, new EventHandler(OnExit)));
        }
        private ToolStrip CreateReportToolbar()
        {
            return new ToolStrip(new ToolStripButton[]
            {
                CreateToolStripButton("½", Properties.Resources.CmdNewReport, new EventHandler(OnNew), "½"),
                CreateToolStripButton("", Properties.Resources.CmdOpen, new EventHandler(OnOpen), ""),
                CreateToolStripButton("", Properties.Resources.CmdSave, new EventHandler(OnSave), "")
            });
        }
        //Getting the Designer to open a new Report on Menu Item "New" click
        private void OnNew(object sender, EventArgs e)
        {
            if (this.ConfirmSaveChanges())
            {
                // ʾԶģѡԻ
                ReportTemplates dlgTemplates = new ReportTemplates();
                if (dlgTemplates.ShowDialog() == System.Windows.Forms.DialogResult.OK)
                {                    
                    switch (dlgTemplates.ReportType)
                    {
                        case DesignerReportType.Page:
                            LayoutBuilder.BuildPageReportLayout(reportDesigner);
                            break;
                        case DesignerReportType.Rdl:
                            LayoutBuilder.BuildRdlReportLayout(reportDesigner);
                            break;
                        case DesignerReportType.Section:
                            LayoutBuilder.BuildSectionReportLayout(reportDesigner);
                            break;
                        default:
                            break;
                    }
                }
            }
        }
        //Getting the Designer to open a Report on Menu Item "Open" click
        private void OnOpen(object sender, EventArgs e)
        {
            if (ConfirmSaveChanges())
            {
                reportDesigner.ExecuteAction(DesignerAction.FileOpen);
            }
        }
        //Getting the Designer to Save the Report on Menu Item "Save" click
        private void OnSave(object sender, EventArgs e)
        {
            reportDesigner.ExecuteAction(DesignerAction.FileSave);
        }
        //Getting the Designer to Save the Report on Menu Item "Save As" click
        private void OnSaveAs(object sender, EventArgs e)
        {
            reportDesigner.ExecuteAction(DesignerAction.FileSave);
        }
        
        // Ԥ
        private void OnViewReport(object sender, EventArgs e)
        {
            ReportViewer viewer = new ReportViewer();
            viewer.Report = reportDesigner.Report;
            viewer.ReportType = reportDesigner.ReportType;
            viewer.ShowDialog();
        }
        private void OnExit(object sender, EventArgs e)
        {
            Close();
        }
        //Checking whether modifications have been made to the report loaded to the designer
        private bool ConfirmSaveChanges()
        {
            if (reportDesigner.IsDirty)
            {
                DialogResult result = MessageBox.Show("Ƿ񱣴浱ǰ?", "", MessageBoxButtons.YesNoCancel, MessageBoxIcon.Question);
                if (result == DialogResult.Cancel)
                {
                    return false;
                }
                if (result == DialogResult.Yes)
                {
                    using (SaveFileDialog saveDialog = new SaveFileDialog())
                    {
                        saveDialog.Filter = "rdlx files|*.rdlx";
                        saveDialog.DefaultExt = ".rdlx";
                        saveDialog.InitialDirectory = new DirectoryInfo(Application.ExecutablePath).Parent.Parent.Parent.FullName;
                        if (saveDialog.ShowDialog() == DialogResult.OK)
                        {
                            reportDesigner.SaveReport(new FileInfo(saveDialog.FileName));
                            reportDesigner.IsDirty = false;
                        }
                    }
                }
            }

            return true;
        }
        private void AppendToolStrips(int row, IList<ToolStrip> toolStrips)
        {
            ToolStripPanel topToolStripPanel = toolStripContainer.TopToolStripPanel;
            int num = toolStrips.Count;
            while (--num >= 0)
            {
                topToolStripPanel.Join(toolStrips[num], row);
            }
        }
        private static ToolStripButton CreateToolStripButton(string text, Image image, EventHandler handler, string toolTip)
        {
            return new ToolStripButton(text, image, handler)
            {
                DisplayStyle = ToolStripItemDisplayStyle.Image,
                ToolTipText = toolTip,
                DoubleClickEnabled = true
            };
        }
        private void ReportsForm_Load(object sender, EventArgs e)
        {
            // Ĭϼ򱨱
            LayoutBuilder.BuildSectionReportLayout(this.reportDesigner);

            // Ĭϼҳ汨
            //LayoutBuilder.BuildPageReportLayout(this.reportDesigner);

            // ĬϼRDL
            //LayoutBuilder.BuildRdlReportLayout(this.reportDesigner);

        }
    }
}
